@@ -41,6 +41,10 @@
 #' If the parameter 'mask' is set to TRUE and the object is of class chromR (which has a mask slot), this mask is used to subset the data.
 #' If an index is supplied as 'mask', then this index is used, and recycled as necessary, to subset the data.
 #' 
+#' Because vcfR provides the opportunity to manipulate VCF data, it also provides the opportunity for the user to create invalid VCF files.
+#' If there is a question regarding the validity of a file you have created one option is the \href{https://vcftools.github.io/perl_module.html#vcf-validator}{VCF validator} from VCF tools.
+#' 
+#' 
 #' @return read.vcfR returns an object of class \code{\link{vcfR-class}}.
 #' See the \strong{vignette:} \code{vignette('vcf_data')}.
 #' The function write.vcf creates a gzipped VCF file.
@@ -148,7 +152,11 @@ write.vcf <- function(x, file = "", mask = FALSE, APPEND = FALSE){
   
   if(APPEND == FALSE){
     gz <- gzfile(file, "w")
-    write(x@meta, gz)
+    
+    if( length(x@meta) > 0 ){
+      write(x@meta, gz)
+    }
+    
     header <- c(colnames(x@fix), colnames(x@gt))
     header[1] <- "#CHROM"
     header <- paste(header, collapse="\t")
