@@ -10,7 +10,10 @@
 class vcfRCommon
 {
 public:
+  // char& is a reference to a char.
+  // https://isocpp.org/wiki/faq/references
   static void strsplit(std::string&, std::vector<std::string>&, char&);
+  static void gtsplit(std::string&, std::vector<std::string>&, int&);
 //  static void strsplit(unsigned char[]&, std::vector<std::string>&, char&);
 };
 
